import { BasicColumn, FormSchema } from '@/components/Table';
import { DescItem } from '@/components/Description';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'workSpaceName',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'createBy',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 120,
    sorter: true,
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 120,
    sorter: true,
  },
];
export const previewColumns: BasicColumn[] = [
  {
    title: 'id',
    dataIndex: 'id',
    width: 150,
  },
  {
    title: 'em_name',
    dataIndex: 'emName',
    width: 120,
  },
  {
    title: 'em_age',
    dataIndex: 'emAge',
    width: 120,
  },
  {
    title: 'em_idcard',
    dataIndex: 'emIdcard',
    width: 120,
  },
  {
    title: 'em_tel',
    dataIndex: 'emTel',
    width: 120,
  },
  {
    title: 'em_typework',
    dataIndex: 'emTypework',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
];
export const formSchema: FormSchema[] = [
  {
    field: 'name',
    label: '数据连接',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: 'mysql',
          value: 'mysql',
        },
        {
          label: 'oracle',
          value: 'oracle',
        },
        {
          label: 'sqlserver',
          value: 'sqlserver',
        },
      ],
    },
    defaultValue: 'mysql',
  },
];
export const CompareFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '文件版本',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: 'V1',
          value: 'V1',
        },
        {
          label: 'V2',
          value: 'V2',
        },
        {
          label: 'V3',
          value: 'V3',
        },
      ],
    },
    defaultValue: 'V1',
  },
];
export const recommendColumns: BasicColumn[] = [
  {
    title: '参数名',
    dataIndex: 'name',
    editable: true,
    edit: true,
    width: 120,
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    editable: true,
    edit: true,
    width: 120,
  },
];
export const recordColumns: BasicColumn[] = [
  {
    title: '执行人',
    dataIndex: 'user',
    width: 120,
  },
  {
    title: '执行时间',
    dataIndex: 'date',
    width: 120,
  },
  {
    title: '执行结果',
    dataIndex: 'result',
    width: 120,
  },
  {
    title: '执行耗时',
    dataIndex: 'cost',
    width: 120,
  },
  {
    title: '影响行数',
    dataIndex: 'log',
    width: 120,
  },
];
export const refundSchema: DescItem[] = [
  {
    field: 'result',
    label: '执行结果',
  },
  {
    field: 'cost',
    label: '执行耗时',
  },
  {
    field: 'user',
    label: '执行人',
  },
  {
    field: 'date',
    label: '执行时间',
  },
  {
    field: 'log',
    label: '影响行数',
  },
];
export const partitionColumns: BasicColumn[] = [
  {
    title: 'name',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: 'partitionKey',
    dataIndex: 'partitionKey',
    width: 120,
  },
  {
    title: 'partitionKeyType',
    dataIndex: 'partitionKeyType',
    width: 120,
  },
  {
    title: 'partitionSize',
    dataIndex: 'partitionSize',
    width: 120,
  },
];
export const resultViewSchema: FormSchema[] = [
  {
    field: 'name',
    label: '图表名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'type',
    label: '图表类型',
    component: 'Select',
    componentProps: {
      options: [{ label: '柱状图', value: '1' }],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'XData',
    label: 'x轴',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'name', value: '1' },
        { label: 'partitionKey', value: '2' },
        { label: 'partitionKeyType', value: '3' },
        { label: 'partitionSize', value: '4' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'YData',
    label: 'y轴',
    component: 'Select',
    componentProps: {
      mode: 'multiple',
      options: [
        { label: 'name', value: '1' },
        { label: 'partitionKey', value: '2' },
        { label: 'partitionKeyType', value: '3' },
        { label: 'partitionSize', value: '4' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'Sum',
    label: '聚合方式',
    component: 'Select',
    componentProps: {
      options: [{ label: 'SUM', value: '1' }],
    },
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'limit',
    label: 'limit',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
];
