import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
    slots: { customRender: 'name' },
  },
  {
    title: '数据源',
    dataIndex: 'dataSource',
    slots: { customRender: 'dataSource' },
    width: 150,
  },
  {
    title: '模板编号',
    dataIndex: 'templateNumber',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 100,
  },
  {
    title: '权属工作组',
    dataIndex: 'workgroup',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // border: 'none',
      fieldNames: {
        label: 'QualityName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];

export const formSchemaNewFolder: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'QualityName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },

  {
    field: 'name',
    label: '文件夹名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件夹名称',
    },
  },
  {
    field: 'fileType',
    label: '权限模式',
    component: 'RadioGroup',
    defaultValue: '本级定义',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '本级定义', value: '本级定义' },
        { label: '资源自定义', value: '资源自定义' },
      ],
      placeholder: '输入描述',
    },
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Select',
    defaultValue: '默认工作组',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入描述',
      options: [{ label: '默认工作组', value: '默认工作组' }],
    },
  },
];

export const formSchemaTemplate: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'QualityName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },

  {
    field: 'name',
    label: '文件名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件夹名称',
    },
    required: true,
  },
  {
    field: 'fileType',
    label: '文件类型',
    component: 'Input',
    defaultValue: '质量模板',
    colProps: { span: 8 },
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'dataSource',
    label: '支持数据源',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      mode: 'multiple',
      options: [
        { label: 'INCEPTOR', value: 'INCEPTOR' },
        { label: 'IMPALA', value: 'IMPALA' },
        { label: 'MYSQL', value: 'MYSQL' },
      ],
    },
    required: true,
  },
  {
    field: 'model',
    label: '目录权属模式',
    component: 'RadioGroup',
    defaultValue: '本级定义',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '本级定义', value: '本级定义' },
        { label: '资源自定义', value: '资源自定义' },
      ],
    },
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Select',
    defaultValue: '默认工作组',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入描述',
      options: [{ label: '默认工作组', value: '默认工作组' }],
    },
  },
];
export const importFormSchema: any[] = [
  {
    field: 'fileMethods',
    label: '导入文件选择',
    slot: 'fileMethods',
    colProps: { lg: 24, md: 24, offset: 3 },
  },
  {
    field: 'fileRename',
    label: '文件重名',
    component: 'RadioGroup',
    required: true,
    colProps: { lg: 24, md: 24, offset: 3 },
    componentProps: {
      options: [
        { label: '全部放弃', value: '1' },
        { label: '全部替换', value: '2' },
        { label: '自动重命名', value: '3' },
      ],
    },
  },
];
